import { jest, describe, expect, it, beforeAll } from '@jest/globals';
import { createWrapper } from 'app/tests/jest/jestHelpers';
import Leftmenu from '../LeftMenu.vue';

import { createTestingPinia } from '@pinia/testing';
import { useNavigationStore } from 'src/stores/useNavigationStore';

const mockPush = jest.fn();

jest.mock('vue-router', () => ({
    useRouter: () => ({
        push: mockPush,
        currentRoute: { value: 'myCurrentRoute' },
    }),
    useRoute: () => ({
        matched: [],
    }),
}));

jest.mock('src/router/modules', () => [
    {
        path: '/customer',
        name: 'Customer',
        meta: {
            title: 'customers',
            icon: 'vn:client',
        },
        menus: {
            main: ['CustomerList', 'CustomerCreate'],
            card: ['CustomerBasicData'],
        },
        children: [
            {
                path: '',
                name: 'CustomerMain',
                children: [
                    {
                        path: 'list',
                        name: 'CustomerList',
                        meta: {
                            title: 'list',
                            icon: 'view_list',
                        },
                    },
                    {
                        path: 'create',
                        name: 'CustomerCreate',
                        meta: {
                            title: 'createCustomer',
                            icon: 'vn:addperson',
                        },
                    },
                ],
            },
        ],
    },
]);

describe('Leftmenu', () => {
    let vm;
    let navigation;
    beforeAll(async () => {
        vm = createWrapper(Leftmenu, {
            propsData: {
                source: 'main',
            },
            global: {
                plugins: [createTestingPinia({ stubActions: false })],
            },
        }).vm;

        navigation = useNavigationStore();
        navigation.modules = ['customer']; // I should mock to have just one module but isn´t working
        navigation.fetchPinned = jest.fn().mockReturnValue(Promise.resolve(true));
        navigation.getModules = jest.fn().mockReturnValue({
            value: [
                {
                    name: 'customer',
                    title: 'customer.pageTitles.customers',
                    icon: 'vn:customer',
                    module: 'customer',
                },
            ],
        });
    });

    it('should return a proper formated object with two child items', async () => {
        const expectedMenuItem = [
            {
                name: 'CustomerList',
                title: 'customer.pageTitles.list',
                icon: 'view_list',
            },
            {
                name: 'CustomerCreate',
                title: 'customer.pageTitles.createCustomer',
                icon: 'vn:addperson',
            },
        ];

        const firstMenuItem = vm.items[0];
        expect(firstMenuItem.children).toEqual(expect.arrayContaining(expectedMenuItem));
    });
});
